@@ -1,4 +1,4 @@
-/*  $Id: launcher.c 29740 2009-04-09 19:18:52Z nick $
+/*  $Id$
  *
  *  Copyright (c) 2005-2007 Jasper Huijsmans <jasper@xfce.org>
  *  Copyright (c) 2006-2007 Nick Schermer <nick@xfce.org>
@@ -254,7 +254,7 @@ launcher_utility_query_tooltip (GtkWidget     *widget,
     {
         if (entry->comment)
         {
-            string = g_strdup_printf ("<b>%s</b>\n%s", entry->name, entry->comment);
+            string = g_markup_printf_escaped ("<b>%s</b>\n%s", entry->name, entry->comment);
             gtk_tooltip_set_markup (tooltip, string);
             g_free (string);
         }
@@ -425,7 +425,7 @@ launcher_icon_button_set_tooltip (LauncherPlugin *launcher)
     /* create tooltip text */
     if (entry != NULL
         && entry->name 
-        && launcher->arrow_position != LAUNCHER_ARROW_INSIDE_BUTTON))
+        && launcher->arrow_position != LAUNCHER_ARROW_INSIDE_BUTTON)
     {
         if (entry->comment)
             string = g_strdup_printf ("%s\n%s", entry->name, entry->comment);
